@@ -99,6 +99,16 @@ def group_for(tlist):
                     sql.For, True)
 
 
+def group_foreach(tlist):
+    _group_matching(tlist, T.Keyword, 'FOREACH', T.Keyword, 'END LOOP',
+                    sql.For, True)
+
+
+def group_begin(tlist):
+    _group_matching(tlist, T.Keyword, 'BEGIN', T.Keyword, 'END',
+                    sql.Begin, True)
+
+
 def group_as(tlist):
 
     def _right_valid(token):
@@ -147,6 +157,7 @@ def group_identifier(tlist):
             lambda y: (y.ttype in (T.String.Symbol,
                                    T.Name,
                                    T.Wildcard,
+                                   T.Literal.String.Single,
                                    T.Literal.Number.Integer,
                                    T.Literal.Number.Float)
                        or isinstance(y, (sql.Parenthesis, sql.Function)))))
@@ -286,7 +297,7 @@ def group_where(tlist):
      if not isinstance(sgroup, sql.Where)]
     idx = 0
     token = tlist.token_next_match(idx, T.Keyword, 'WHERE')
-    stopwords = ('ORDER', 'GROUP', 'LIMIT', 'UNION')
+    stopwords = ('ORDER', 'GROUP', 'LIMIT', 'UNION', 'EXCEPT')
     while token:
         tidx = tlist.token_index(token)
         end = tlist.token_next_match(tidx + 1, T.Keyword, stopwords)
@@ -369,5 +380,7 @@ def group(tlist):
             group_comparison,
             group_identifier_list,
             group_if,
-            group_for]:
+            group_for,
+            group_foreach,
+            group_begin]:
         func(tlist)
