@@ -301,7 +301,7 @@ class ReindentFilter:
     def _split_kwds(self, tlist):
         split_words = ('FROM', 'STRAIGHT_JOIN$', 'JOIN$', 'AND', 'OR',
                        'GROUP', 'ORDER', 'UNION', 'VALUES',
-                       'SET', 'BETWEEN')
+                       'SET', 'BETWEEN', 'EXCEPT')
 
         def _next_token(i):
             t = tlist.token_next_match(i, T.Keyword, split_words,
